;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "cond-let" "1.1.3"
  "Additional and improved binding conditionals."
  '((emacs "28.1"))
  :url "https://github.com/tarsius/cond-let"
  :commit "c48600dfab6372670225f046cace263700c78eab"
  :revdesc "v1.1.3-0-gc48600dfab63"
  :keywords '("extensions")
  :authors '(("Jonas Bernoulli" . "emacs.cond-let@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.cond-let@jonas.bernoulli.dev")))
